@@ -120,20 +120,22 @@ class TestJobLock(unittest.TestCase, contextlib.ExitStack):
     with open(self.tmpdir/"lock1.lock_2", "w") as f: pass
     with open(self.tmpdir/"lock1.lock_5", "w") as f: pass
     with open(self.tmpdir/"lock1.lock_30", "w") as f: pass
-    time.sleep(.1)
+    time.sleep(1)
     with open(self.tmpdir/"lock1.lock_10", "w") as f: pass
     with open(self.tmpdir/"lock1.lock", "w") as f: pass
-    with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=.1)) as lock:
+    with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=1)) as lock:
       self.assertFalse(lock)
     self.assertFalse((self.tmpdir/"lock1.lock_2").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_5").exists())
     self.assertTrue((self.tmpdir/"lock1.lock_10").exists())
-    self.assertFalse((self.tmpdir/"lock1.lock_30").exists())
-    time.sleep(.1)
+    self.assertTrue((self.tmpdir/"lock1.lock_30").exists())
+    time.sleep(1)
     with JobLock(self.tmpdir/"lock1.lock") as lock:
       self.assertFalse(lock)
     with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=10)) as lock:
       self.assertFalse(lock)
-    with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=.1)) as lock:
+    with JobLock(self.tmpdir/"lock1.lock", corruptfiletimeout=datetime.timedelta(seconds=1)) as lock:
       self.assertTrue(lock)
+    self.assertFalse((self.tmpdir/"lock1.lock_5").exists())
     self.assertFalse((self.tmpdir/"lock1.lock_10").exists())
+    self.assertFalse((self.tmpdir/"lock1.lock_30").exists())
